pub fn init_codec()Expand description
Initialize the codec from the AGENTOS_V8_CODEC environment variable. Call once at process startup before any sessions are created.
pub fn init_codec()Initialize the codec from the AGENTOS_V8_CODEC environment variable. Call once at process startup before any sessions are created.