pub fn extract_process_exit_code(
scope: &mut HandleScope<'_>,
exception: Local<'_, Value>,
) -> Option<i32>Expand description
Check if a V8 exception is a ProcessExitError (has _isProcessExit: true sentinel).
Returns Some(exit_code) if detected, None otherwise.
ProcessExitError is detected by sentinel property, not by regex matching on the error message or constructor name.