pub fn create_context(isolate: &mut OwnedIsolate) -> Global<Context>Expand description
Create a new V8 context on the given isolate. Returns a Global handle so the context can be reused across scopes.
pub fn create_context(isolate: &mut OwnedIsolate) -> Global<Context>Create a new V8 context on the given isolate. Returns a Global handle so the context can be reused across scopes.