pub fn install_session_guest_reader(reader: Option<Box<dyn GuestModuleReader>>)Expand description
Install (or clear) the direct module reader for the current session thread.
Called by the session thread when it receives a SetModuleReader command; the
next execute_module moves it into the resolve state. Must be called on the
session/isolate thread.